==> common-core-1.1.1-sources.jar: com/bxm/game/common/core/prop/dao/RedisPropDaoImpl.java <==
package com.bxm.game.common.core.prop.dao;

import com.bxm.game.common.core.AppConfig;
import com.bxm.game.common.core.Key;
import com.bxm.game.common.core.prop.AcquiredPropLog;
import com.bxm.warcar.cache.Fetcher;
import com.bxm.warcar.cache.KeyGenerator;
import com.bxm.warcar.cache.Updater;
import com.bxm.warcar.utils.KeyBuilder;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;

import java.util.Objects;
import java.util.Optional;

/**
 * @author allen
 * @date 2020-12-15
 * @since 1.0
 */
@ConditionalOnProperty(name = "game.datasource.type", havingValue = "redis", matchIfMissing = true)
public class RedisPropDaoImpl implements PropDao {

    private final AppConfig appConfig;
    private final Fetcher fetcher;
    private final Updater updater;

    public RedisPropDaoImpl(AppConfig appConfig, Fetcher fetcher, Updater updater) {
        this.appConfig = appConfig;
        this.fetcher = fetcher;
        this.updater = updater;
    }

    @Override
    public boolean saveTakeLog(AcquiredPropLog log) {
        if (Objects.isNull(log) || Objects.isNull(log.getId())) {
            return true;
        }
        updater.update(hash(log.getId()), log, Key.EXPIRE_TIME_ONE_DAY * 2);
        return true;
    }

    @Override
    public AcquiredPropLog getTakeLog(String id) {
        AcquiredPropLog propLog = fetcher.fetch(hash(id), AcquiredPropLog.class);
        return Optional.ofNullable(propLog).orElse(null);
    }

    private KeyGenerator hash(String id) {
        return () -> KeyBuilder.build("game", appConfig.getNamespace(), "take_log", id);
    }
}

==> common-core-1.3.1.1-sources.jar: com/bxm/game/common/core/prop/dao/RedisPropDaoImpl.java <==
package com.bxm.game.common.core.prop.dao;

import java.util.Objects;
import java.util.Optional;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;

import com.bxm.game.common.core.AppConfig;
import com.bxm.game.common.core.prop.AcquiredPropLog;
import com.bxm.warcar.cache.Fetcher;
import com.bxm.warcar.cache.KeyGenerator;
import com.bxm.warcar.cache.Updater;
import com.bxm.warcar.utils.KeyBuilder;

/**
 * @author allen
 * @date 2020-12-15
 * @since 1.0
 */
@ConditionalOnProperty(name = "game.datasource.type", havingValue = "redis", matchIfMissing = true)
public class RedisPropDaoImpl implements PropDao {

    private final AppConfig appConfig;
    private final Fetcher fetcher;
    private final Updater updater;

    public RedisPropDaoImpl(AppConfig appConfig, Fetcher fetcher, Updater updater) {
        this.appConfig = appConfig;
        this.fetcher = fetcher;
        this.updater = updater;
    }

    @Override
    public boolean saveTakeLog(AcquiredPropLog log) {
        if (Objects.isNull(log) || Objects.isNull(log.getId())) {
            return true;
        }
        updater.update(hash(log.getId()), log, appConfig.ttlTakeLog());
        return true;
    }

    @Override
    public AcquiredPropLog getTakeLog(String id) {
        AcquiredPropLog propLog = fetcher.fetch(hash(id), AcquiredPropLog.class);
        return Optional.ofNullable(propLog).orElse(null);
    }

    private KeyGenerator hash(String id) {
        return () -> KeyBuilder.build("game", appConfig.getNamespace(), "take_log", id);
    }
}
